dev.skivi.config.interface

Configuration management interface with malli schema metadata.

All functions have :malli/schema metadata for runtime validation. To enable instrumentation:

(require '[malli.instrument :as mi]) (mi/instrument!) ; instruments all functions with :malli/schema metadata (mi/unstrument!) ; removes instrumentation

Configuration management interface with malli schema metadata.

All functions have :malli/schema metadata for runtime validation.
To enable instrumentation:

  (require '[malli.instrument :as mi])
  (mi/instrument!)  ; instruments all functions with :malli/schema metadata
  (mi/unstrument!)  ; removes instrumentation
raw docstring

cleanup-configclj

(cleanup-config config)

Returns the cleanup configuration map from config.

Returns the cleanup configuration map from config.
sourceraw docstring

cleanup-config*clj

(cleanup-config*)

Returns the cleanup configuration map from the dynamic var.

Returns the cleanup configuration map from the dynamic var.
sourceraw docstring

Configclj

source

database-configclj

(database-config config)

Returns the database configuration map from config.

Returns the database configuration map from config.
sourceraw docstring

database-config*clj

(database-config*)

Returns the database configuration map from the dynamic var.

Returns the database configuration map from the dynamic var.
sourceraw docstring

get-configclj

(get-config)

Returns the current configuration from the dynamic var. Throws if configuration has not been loaded.

Returns the current configuration from the dynamic var. Throws if configuration
has not been loaded.
sourceraw docstring

load-configclj

(load-config)
(load-config filename)
(load-config filename opts)

Reads and validates configuration from filename using aero. With no arguments, loads configuration with the following precedence:

  1. Checks for 'skivi-config.edn' (dedicated file, root-level config)
  2. Falls back to :skivi section in 'config.edn' (embedded in shared config)

Opts map may include :profile for environment-specific config. Throws if configuration is invalid or not found.

Reads and validates configuration from filename using aero. With no arguments,
loads configuration with the following precedence:

1. Checks for 'skivi-config.edn' (dedicated file, root-level config)
2. Falls back to :skivi section in 'config.edn' (embedded in shared config)

Opts map may include :profile for environment-specific config.
Throws if configuration is invalid or not found.
sourceraw docstring

logging-configclj

(logging-config config)

Returns the logging configuration map from config.

Returns the logging configuration map from config.
sourceraw docstring

logging-config*clj

(logging-config*)

Returns the logging configuration map from the dynamic var.

Returns the logging configuration map from the dynamic var.
sourceraw docstring

monitoring-configclj

(monitoring-config config)

Returns the monitoring configuration map from config.

Returns the monitoring configuration map from config.
sourceraw docstring

monitoring-config*clj

(monitoring-config*)

Returns the monitoring configuration map from the dynamic var.

Returns the monitoring configuration map from the dynamic var.
sourceraw docstring

queue-configclj

(queue-config config)

Returns the queue configuration map from config.

Returns the queue configuration map from config.
sourceraw docstring

queue-config*clj

(queue-config*)

Returns the queue configuration map from the dynamic var.

Returns the queue configuration map from the dynamic var.
sourceraw docstring

reload-config!clj

(reload-config! system)
(reload-config! system filename)

Reloads configuration and updates system. System can be:

  • Map with :config atom key (returns updated system map)
  • Atom directly (returns dereferenced new config)
  • nil (returns new config without updating anything)

Optional filename parameter specifies which config file to reload.

Reloads configuration and updates system. System can be:
 - Map with :config atom key (returns updated system map)
 - Atom directly (returns dereferenced new config)
 - nil (returns new config without updating anything)

Optional filename parameter specifies which config file to reload.
sourceraw docstring

retry-configclj

(retry-config config)

Returns the retry configuration map from config.

Returns the retry configuration map from config.
sourceraw docstring

retry-config*clj

(retry-config*)

Returns the retry configuration map from the dynamic var.

Returns the retry configuration map from the dynamic var.
sourceraw docstring

scheduler-configclj

(scheduler-config config)

Returns the scheduler/cron configuration map from config.

Returns the scheduler/cron configuration map from config.
sourceraw docstring

scheduler-config*clj

(scheduler-config*)

Returns the scheduler/cron configuration map from the dynamic var.

Returns the scheduler/cron configuration map from the dynamic var.
sourceraw docstring

schema-nameclj

(schema-name config)

Returns the database schema name string from config.

Returns the database schema name string from config.
sourceraw docstring

schema-name*clj

(schema-name*)

Returns the database schema name string from the dynamic var.

Returns the database schema name string from the dynamic var.
sourceraw docstring

validate-configclj

(validate-config config)

Returns config if it conforms to the Config schema, otherwise throws ex-info with humanised validation errors.

Returns config if it conforms to the Config schema, otherwise throws ex-info
with humanised validation errors.
sourceraw docstring

with-configclj

(with-config config f)

Evaluates f with config bound to the dynamic configuration var. Returns the result of calling f.

Evaluates f with config bound to the dynamic configuration var. Returns the
result of calling f.
sourceraw docstring

worker-configclj

(worker-config config)

Returns the worker configuration map from config.

Returns the worker configuration map from config.
sourceraw docstring

worker-config*clj

(worker-config*)

Returns the worker configuration map from the dynamic var.

Returns the worker configuration map from the dynamic var.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries