dev.skivi.database.dsl


any-idsclj

(any-ids ids)

Return a HoneySQL :in clause matching id against ids.

Return a HoneySQL :in clause matching id against ids.
sourceraw docstring

by-correlationclj

(by-correlation q cid)

Append WHERE correlation_id = cid to a HoneySQL query.

Append WHERE correlation_id = cid to a HoneySQL query.
sourceraw docstring

by-idclj

(by-id q id)

Append WHERE id = id to a HoneySQL query.

Append WHERE id = id to a HoneySQL query.
sourceraw docstring

by-job-idclj

(by-job-id q job-id)

Append WHERE job_id = job-id to a HoneySQL query.

Append WHERE job_id = job-id to a HoneySQL query.
sourceraw docstring

by-workerclj

(by-worker q worker-id)

Append WHERE worker_id = worker-id to a HoneySQL query.

Append WHERE worker_id = worker-id to a HoneySQL query.
sourceraw docstring

crontab-stateclj

(crontab-state identifier)

Build a SELECT query for last_execution and known_since by identifier.

Build a SELECT query for last_execution and known_since by identifier.
sourceraw docstring

job-historyclj

(job-history q)

Append FROM job_history to a HoneySQL query.

Append FROM job_history to a HoneySQL query.
sourceraw docstring

job-history-by-correlationclj

(job-history-by-correlation cid)

Build a SELECT * FROM job_history query for correlation cid, newest first.

Build a SELECT * FROM job_history query for correlation cid, newest first.
sourceraw docstring

job-history-by-job-idclj

(job-history-by-job-id job-id)

Build a SELECT * FROM job_history query for job-id, newest first.

Build a SELECT * FROM job_history query for job-id, newest first.
sourceraw docstring

jobsclj

(jobs q)

Append FROM jobs to a HoneySQL query.

Append FROM jobs to a HoneySQL query.
sourceraw docstring

locked-job-queue-namesclj

(locked-job-queue-names worker-ids)

Build a SELECT query for queue_name of locked jobs. Restricted to worker-ids when provided.

Build a SELECT query for queue_name of locked jobs.
Restricted to worker-ids when provided.
sourceraw docstring

mark-job-completedclj

(mark-job-completed job-id worker-id cid execution-time-ms)

Build an UPDATE job_history query to mark a started record as completed.

Build an UPDATE job_history query to mark a started record as completed.
sourceraw docstring

mark-job-failedclj

(mark-job-failed job-id worker-id cid execution-time-ms err-msg err-stack)

Build an UPDATE job_history query to mark a started record as failed.

Build an UPDATE job_history query to mark a started record as failed.
sourceraw docstring

mark-job-partialclj

(mark-job-partial job-id worker-id cid execution-time-ms partial)

Build an UPDATE job_history query to mark a started record as partial_success.

Build an UPDATE job_history query to mark a started record as partial_success.
sourceraw docstring

newest-firstclj

(newest-first q)

Append ORDER BY created_at DESC to a HoneySQL query.

Append ORDER BY created_at DESC to a HoneySQL query.
sourceraw docstring

nowclj

(now)

Return a HoneySQL raw SQL expression for the current timestamp.

Return a HoneySQL raw SQL expression for the current timestamp.
sourceraw docstring

query-historyclj

(query-history {:keys [from to task-identifier status limit]})

Build a SELECT * FROM job_history query filtered by criteria map. Criteria keys (all optional): :from, :to (inst?), :task-identifier, :status, :limit.

Build a SELECT * FROM job_history query filtered by criteria map.
Criteria keys (all optional): :from, :to (inst?), :task-identifier, :status, :limit.
sourceraw docstring

rescheduleclj

(reschedule job-ids {:keys [run-at priority max-attempts]})

Build an UPDATE jobs query to reschedule job-ids. Returns nil if no fields to update.

Build an UPDATE jobs query to reschedule job-ids. Returns nil if no fields to update.
sourceraw docstring

returning-allclj

(returning-all q)

Append RETURNING * to a HoneySQL query.

Append RETURNING * to a HoneySQL query.
sourceraw docstring

sqlvecclj

(sqlvec q)

Format a HoneySQL query map to a JDBC-ready SQL vector.

Format a HoneySQL query map to a JDBC-ready SQL vector.
sourceraw docstring

started-onlyclj

(started-only q)

Append WHERE status = 'started' to a HoneySQL query.

Append WHERE status = 'started' to a HoneySQL query.
sourceraw docstring

status-isclj

(status-is q status)

Append WHERE status = status to a HoneySQL query.

Append WHERE status = status to a HoneySQL query.
sourceraw docstring

touch-last-executionclj

(touch-last-execution identifier)

Build an UPDATE known_crontabs query to set last_execution = now() by identifier.

Build an UPDATE known_crontabs query to set last_execution = now() by identifier.
sourceraw docstring

unlock-jobsclj

(unlock-jobs worker-ids)

Build an UPDATE jobs query to clear locks. Restricted to worker-ids when provided.

Build an UPDATE jobs query to clear locks. Restricted to worker-ids when provided.
sourceraw docstring

unlock-queuesclj

(unlock-queues queue-names)

Build an UPDATE job_queues query to clear locks. Restricted to queue-names when provided.

Build an UPDATE job_queues query to clear locks. Restricted to queue-names when provided.
sourceraw docstring

upsert-crontabclj

(upsert-crontab identifier)

Build an INSERT ... ON CONFLICT DO NOTHING query for known_crontabs.

Build an INSERT ... ON CONFLICT DO NOTHING query for known_crontabs.
sourceraw docstring

upsert-task-identifierclj

(upsert-task-identifier identifier)

Build an INSERT ... ON CONFLICT DO UPDATE query for task_identifiers.

Build an INSERT ... ON CONFLICT DO UPDATE query for task_identifiers.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries