dev.skivi.job-manager.schema

Malli schemas for job-manager component.

Malli schemas for job-manager component.
raw docstring

correlation-id-keyclj

Key embedded in job maps returned by get-jobs for history record correlation.

Key embedded in job maps returned by get-jobs for history record correlation.
sourceraw docstring

Jobclj

Job record. When returned from get-jobs, contains ::correlation-id for history tracking.

Job record. When returned from get-jobs, contains ::correlation-id for history tracking.
sourceraw docstring

JobErrorclj

Failure pairing: the job that failed and the error cause.

Failure pairing: the job that failed and the error cause.
sourceraw docstring

JobManagerSystemclj

Runtime system map providing a database pool and payload validator.

Runtime system map providing a database pool and payload validator.
sourceraw docstring

JobSpecclj

Specification for creating a job.

Specification for creating a job.
sourceraw docstring

PartialResultsclj

Outcome of a partially successful job execution.

Outcome of a partially successful job execution.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries