dev.skivi.maintenance.interface

Maintenance scheduler: reset-locked-jobs and refill-rate-limits run on a short interval; GC tasks run on a configurable cron schedule.

Maintenance scheduler: reset-locked-jobs and refill-rate-limits run on a short
interval; GC tasks run on a configurable cron schedule.
raw docstring

create-schedulerclj

(create-scheduler job-system)
(create-scheduler job-system config)

Creates a maintenance scheduler. Call start! to begin processing. job-system is {:pool datasource :validator validator}. config keys: :maintenance-interval-ms, :schedule, :tasks, :timezone, :retention-periods.

Creates a maintenance scheduler. Call start! to begin processing.
job-system is {:pool datasource :validator validator}.
config keys: :maintenance-interval-ms, :schedule, :tasks, :timezone, :retention-periods.
sourceraw docstring

running?clj

(running? sched)

Returns true if the maintenance loop is active.

Returns true if the maintenance loop is active.
sourceraw docstring

start!clj

(start! sched)

Starts the maintenance loop. Throws if already running. Returns scheduler.

Starts the maintenance loop. Throws if already running. Returns scheduler.
sourceraw docstring

statsclj

(stats sched)

Returns a snapshot of maintenance scheduler operational metrics. Keys: :maintenance-runs, :gc-runs, :errors.

Returns a snapshot of maintenance scheduler operational metrics.
Keys: :maintenance-runs, :gc-runs, :errors.
sourceraw docstring

stop!clj

(stop! sched)
(stop! sched timeout-ms)

Signals the loop to stop and waits up to timeout-ms. Returns scheduler.

Signals the loop to stop and waits up to timeout-ms. Returns scheduler.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries