dev.skivi.skivi.core

Unified entry point that wires all skivi components into a single system map.

Typical usage:

(def system (-> (skivi/create-system config {"send-email" handle-send-email}) (skivi/start!)))

(skivi/add-job system "send-email" {:to "x@y.com"})

;; On shutdown (skivi/stop! system)

Unified entry point that wires all skivi components into a single system map.

Typical usage:

  (def system
    (-> (skivi/create-system config {"send-email" handle-send-email})
        (skivi/start!)))

  (skivi/add-job system "send-email" {:to "x@y.com"})

  ;; On shutdown
  (skivi/stop! system)
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries