(any-ids ids)Return a HoneySQL :in clause matching id against ids.
Return a HoneySQL :in clause matching id against ids.
(by-correlation q cid)Append WHERE correlation_id = cid to a HoneySQL query.
Append WHERE correlation_id = cid to a HoneySQL query.
(by-id q id)Append WHERE id = id to a HoneySQL query.
Append WHERE id = id to a HoneySQL query.
(by-job-id q job-id)Append WHERE job_id = job-id to a HoneySQL query.
Append WHERE job_id = job-id to a HoneySQL query.
(by-worker q worker-id)Append WHERE worker_id = worker-id to a HoneySQL query.
Append WHERE worker_id = worker-id to a HoneySQL query.
(crontab-state identifier)Build a SELECT query for last_execution and known_since by identifier.
Build a SELECT query for last_execution and known_since by identifier.
(job-history q)Append FROM job_history to a HoneySQL query.
Append FROM job_history to a HoneySQL query.
(job-history-by-correlation cid)Build a SELECT * FROM job_history query for correlation cid, newest first.
Build a SELECT * FROM job_history query for correlation cid, newest first.
(job-history-by-job-id job-id)Build a SELECT * FROM job_history query for job-id, newest first.
Build a SELECT * FROM job_history query for job-id, newest first.
(jobs q)Append FROM jobs to a HoneySQL query.
Append FROM jobs to a HoneySQL query.
(locked-job-queue-names worker-ids)Build a SELECT query for queue_name of locked jobs. Restricted to worker-ids when provided.
Build a SELECT query for queue_name of locked jobs. Restricted to worker-ids when provided.
(mark-job-completed job-id worker-id cid execution-time-ms)Build an UPDATE job_history query to mark a started record as completed.
Build an UPDATE job_history query to mark a started record as completed.
(mark-job-failed job-id worker-id cid execution-time-ms err-msg err-stack)Build an UPDATE job_history query to mark a started record as failed.
Build an UPDATE job_history query to mark a started record as failed.
(mark-job-partial job-id worker-id cid execution-time-ms partial)Build an UPDATE job_history query to mark a started record as partial_success.
Build an UPDATE job_history query to mark a started record as partial_success.
(newest-first q)Append ORDER BY created_at DESC to a HoneySQL query.
Append ORDER BY created_at DESC to a HoneySQL query.
(now)Return a HoneySQL raw SQL expression for the current timestamp.
Return a HoneySQL raw SQL expression for the current timestamp.
(query-history {:keys [from to task-identifier status limit]})Build a SELECT * FROM job_history query filtered by criteria map. Criteria keys (all optional): :from, :to (inst?), :task-identifier, :status, :limit.
Build a SELECT * FROM job_history query filtered by criteria map. Criteria keys (all optional): :from, :to (inst?), :task-identifier, :status, :limit.
(reschedule job-ids {:keys [run-at priority max-attempts]})Build an UPDATE jobs query to reschedule job-ids. Returns nil if no fields to update.
Build an UPDATE jobs query to reschedule job-ids. Returns nil if no fields to update.
(returning-all q)Append RETURNING * to a HoneySQL query.
Append RETURNING * to a HoneySQL query.
(sqlvec q)Format a HoneySQL query map to a JDBC-ready SQL vector.
Format a HoneySQL query map to a JDBC-ready SQL vector.
(started-only q)Append WHERE status = 'started' to a HoneySQL query.
Append WHERE status = 'started' to a HoneySQL query.
(status-is q status)Append WHERE status = status to a HoneySQL query.
Append WHERE status = status to a HoneySQL query.
(touch-last-execution identifier)Build an UPDATE known_crontabs query to set last_execution = now() by identifier.
Build an UPDATE known_crontabs query to set last_execution = now() by identifier.
(unlock-jobs worker-ids)Build an UPDATE jobs query to clear locks. Restricted to worker-ids when provided.
Build an UPDATE jobs query to clear locks. Restricted to worker-ids when provided.
(unlock-queues queue-names)Build an UPDATE job_queues query to clear locks. Restricted to queue-names when provided.
Build an UPDATE job_queues query to clear locks. Restricted to queue-names when provided.
(upsert-crontab identifier)Build an INSERT ... ON CONFLICT DO NOTHING query for known_crontabs.
Build an INSERT ... ON CONFLICT DO NOTHING query for known_crontabs.
(upsert-task-identifier identifier)Build an INSERT ... ON CONFLICT DO UPDATE query for task_identifiers.
Build an INSERT ... ON CONFLICT DO UPDATE query for task_identifiers.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |