Malli schemas for job-manager component.
Malli schemas for job-manager component.
Key embedded in job maps returned by get-jobs for history record correlation.
Key embedded in job maps returned by get-jobs for history record correlation.
Job record. When returned from get-jobs, contains ::correlation-id for history tracking.
Job record. When returned from get-jobs, contains ::correlation-id for history tracking.
Failure pairing: the job that failed and the error cause.
Failure pairing: the job that failed and the error cause.
Runtime system map providing a database pool and payload validator.
Runtime system map providing a database pool and payload validator.
Outcome of a partially successful job execution.
Outcome of a partially successful job execution.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |