Maintenance scheduler: reset-locked-jobs and refill-rate-limits run on a short interval; GC tasks run on a configurable cron schedule.
Maintenance scheduler: reset-locked-jobs and refill-rate-limits run on a short interval; GC tasks run on a configurable cron schedule.
(create-scheduler job-system)(create-scheduler job-system config)Creates a maintenance scheduler. Call start! to begin processing. job-system is {:pool datasource :validator validator}. config keys: :maintenance-interval-ms, :schedule, :tasks, :timezone, :retention-periods.
Creates a maintenance scheduler. Call start! to begin processing.
job-system is {:pool datasource :validator validator}.
config keys: :maintenance-interval-ms, :schedule, :tasks, :timezone, :retention-periods.(running? sched)Returns true if the maintenance loop is active.
Returns true if the maintenance loop is active.
(start! sched)Starts the maintenance loop. Throws if already running. Returns scheduler.
Starts the maintenance loop. Throws if already running. Returns scheduler.
(stats sched)Returns a snapshot of maintenance scheduler operational metrics. Keys: :maintenance-runs, :gc-runs, :errors.
Returns a snapshot of maintenance scheduler operational metrics. Keys: :maintenance-runs, :gc-runs, :errors.
(stop! sched)(stop! sched timeout-ms)Signals the loop to stop and waits up to timeout-ms. Returns scheduler.
Signals the loop to stop and waits up to timeout-ms. Returns scheduler.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |